@@ -32,7 +32,7 @@ class DataTable(Module):
 
     @classmethod
     def css(cls) -> List[str]:
-        return ["//cdn.datatables.net/1.10.19/css/jquery.dataTables.min.css", f"/custom/labext/{cls.id()}/css/jupyter_data_tables.css"]
+        return ["//cdn.datatables.net/1.10.19/css/jquery.dataTables.min.css"]#, f"/custom/labext/{cls.id()}/css/jupyter_data_tables.css"]
 
     @classmethod
     def js(cls) -> Dict[str, str]:
